@@ -37,8 +37,8 @@ print """Usage: python sum_primes.py [ncpus]
     if omitted it will be set to the number of processors in the system"""
 
 # tuple of all parallel python servers to connect with
-#ppservers = ()
-ppservers = ("127.0.0.1:60000", )
+ppservers = ()
+#ppservers = ("127.0.0.1:60000", )
 
 if len(sys.argv) > 1:
     ncpus = int(sys.argv[1])
