@@ -1,5 +1,5 @@
 # Parallel Python Software: http://www.parallelpython.com
-# Copyright (c) 2005-2012, Vitalii Vanovschi
+# Copyright (c) 2005-2017, Vitalii Vanovschi
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -44,8 +44,8 @@ import pptransport
 import ppauto
 import ppcommon
 
-copyright = "Copyright (c) 2005-2012 Vitalii Vanovschi. All rights reserved"
-version = "1.6.5"
+copyright = "Copyright (c) 2005-2017 Vitalii Vanovschi. All rights reserved"
+version = "1.6.6"
 
 # Reconnect persistent rworkers in seconds.
 RECONNECT_WAIT_TIME = 5
@@ -820,7 +820,7 @@ class Server(object):
             try:
                 worker.t.close()
                 if sys.platform.startswith("win"):
-                    os.popen('TASKKILL /PID '+str(worker.pid)+' /F')
+                    os.popen('TASKKILL /PID '+str(worker.pid)+' /F 2>NUL')
                 else:
                     os.kill(worker.pid, 9)
                     os.waitpid(worker.pid, 0)
