@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # Parallel Python Software: http://www.parallelpython.com
-# Copyright (c) 2005-2012, Vitalii Vanovschi
+# Copyright (c) 2005-2017, Vitalii Vanovschi
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -49,8 +49,8 @@ import ppauto
 import ppcommon
 import pptransport
 
-copyright = "Copyright (c) 2005-2012 Vitalii Vanovschi. All rights reserved"
-version = "1.6.5"
+copyright = "Copyright (c) 2005-2017 Vitalii Vanovschi. All rights reserved"
+version = "1.6.6"
 
 LISTEN_SOCKET_TIMEOUT = 20
 
@@ -223,6 +223,10 @@ def parse_config(file_loc):
         print >> sys.stderr, "ERROR: Can not access %s." % arg
         sys.exit(1)
 
+    args = {}
+    autodiscovery = False
+    debug = False
+
     # Load the configuration file
     config = ConfigObj(file_loc)
     # try each config item and use the result if it exists. If it doesn't
@@ -254,7 +258,7 @@ def parse_config(file_loc):
         pass
 
     try:
-        args['loglevel'] = config['general'].as_bool('debug')
+        debug  = config['general'].as_bool('debug')
     except:
         pass
 
@@ -288,7 +292,7 @@ def parse_config(file_loc):
     except:
         pass
     # Return a tuple of the args dict and autodiscovery variable
-    return args, autodiscovery
+    return args, autodiscovery, debug
 
 
 def print_usage():
@@ -337,6 +341,7 @@ def create_network_server(argv):
 
     args = {}
     autodiscovery = False
+    debug = False
 
     log_level = logging.WARNING
     log_format = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
@@ -346,10 +351,9 @@ def create_network_server(argv):
             print_usage()
             sys.exit()
         elif opt == "-c":
-            args, autodiscovery = parse_config(arg)
+            args, autodiscovery, debug = parse_config(arg)
         elif opt == "-d":
-            log_level = logging.DEBUG
-            pp.SHOW_EXPECTED_EXCEPTIONS = True
+				    debug = True
         elif opt == "-f":
             log_format = arg
         elif opt == "-i":
@@ -374,6 +378,10 @@ def create_network_server(argv):
             args["socket_timeout"] = int(arg)
         elif opt == "-P":
             args["pid_file"] = arg
+	
+    if debug:
+        log_level = logging.DEBUG
+        pp.SHOW_EXPECTED_EXCEPTIONS = True
 
     log_handler = logging.StreamHandler()
     log_handler.setFormatter(logging.Formatter(log_format))
